@@ -99,7 +99,7 @@
     <tags-item tags="vblex.ger"/>
   </def-label>
   <def-label name="VLEXPPRES">
-    <tags-item tags="vblex.ppres"/>
+    <tags-item tags="vblex.ppres.*"/>
   </def-label>
   <def-label name="VLEXPARTPI">
     <tags-item tags="vblex.pp.*"/>
@@ -128,7 +128,7 @@
     <tags-item tags="vbser.ger"/>
   </def-label>
   <def-label name="VSERPPRES" closed="true">
-    <tags-item tags="vbser.ppres"/>
+    <tags-item tags="vbser.ppres.*"/>
   </def-label>
   <def-label name="VSERPARTPI" closed="true">
     <tags-item tags="vbser.pp.*"/>
@@ -157,7 +157,7 @@
     <tags-item tags="vbhaver.ger"/>
   </def-label>
   <def-label name="VHABERPPRES" closed="true">
-    <tags-item tags="vbhaver.ppres"/>
+    <tags-item tags="vbhaver.ppres.*"/>
   </def-label>
   <def-label name="VHABERPARTPI" closed="true">
     <tags-item tags="vbhaver.pp.*"/>
@@ -183,7 +183,7 @@
     <tags-item tags="vbmod.ger"/>
   </def-label>
   <def-label name="VMODALPPRES" closed="true">
-    <tags-item tags="vbmod.ppres"/>
+    <tags-item tags="vbmod.ppres.*"/>
   </def-label>
   <def-label name="VMODALPARTPI" closed="true">
     <tags-item tags="vbmod.pp.*"/>
@@ -239,6 +239,12 @@
       <tags-item tags="det.def.mf.pl"/>
     </sequence>
   </def-mult>
+  <def-mult name="PREPREL" closed="true">
+    <sequence>
+      <label-item label="PREP"/>
+      <label-item label="REL"/>
+    </sequence>
+  </def-mult>
   <def-mult name="IMPLEXPRNENC">
     <sequence>
       <label-item label="VLEXIMP"/>
@@ -968,7 +974,7 @@
     </label-sequence>
     
   <!--prova prohibició verb que no siga être o avoir + participi-->  
-    <label-sequence>
+   <!-- <label-sequence>
       <label-item label="VLEXPFCI"/>
       <label-item label="VLEXPARTPI"/>
     </label-sequence>
@@ -999,7 +1005,7 @@
     <label-sequence>
       <label-item label="VMODALIMP"/>
       <label-item label="VLEXPARTPI"/>
-    </label-sequence>
+    </label-sequence> -->
     
 <!--prova prohibició de nom i adj + ger pq trie ppres-->   
     <label-sequence>
@@ -1137,13 +1143,17 @@
       <label-item label="PREDET"/>
       <label-item label="SENT"/>
     </label-sequence>
-    <label-sequence>
+  <!--  <label-sequence>
       <label-item label="RELN"/>
       <label-item label="SENT"/>
     </label-sequence>
     <label-sequence>
       <label-item label="RELAA"/>
       <label-item label="SENT"/>
+    </label-sequence> --> 
+    <label-sequence>
+      <label-item label="REL"/>
+      <label-item label="SENT"/>
     </label-sequence>
     <label-sequence>
       <label-item label="RELADV"/>
@@ -1447,7 +1457,43 @@
      <label-sequence>
       <label-item label="PRNPRO"/>
       <label-item label="ADV"/>
+    </label-sequence>   
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="NOMM"/>
+    </label-sequence>   
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="NOMF"/>
+    </label-sequence>   
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>   
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="ACRONIMOM"/>
     </label-sequence>  
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="ACRONIMOF"/>
+    </label-sequence>   
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="ACRONIMOMF"/>
+    </label-sequence>    
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="ANTROPONIM"/>
+    </label-sequence>    
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="TOPONIM"/>
+    </label-sequence>    
+     <label-sequence>
+      <label-item label="PRNPRO"/>
+      <label-item label="NPALTRES"/>
+    </label-sequence> 
     
     <label-sequence>
       <label-item label="PRNTN"/>
@@ -1640,7 +1686,7 @@
       <label-item label="NUM"/>
     </label-sequence> 
 
-    <label-sequence>
+  <!--  <label-sequence>
       <label-item label="VHABERPFCI"/>
       <label-item label="ADV"/>
     </label-sequence>
@@ -1658,7 +1704,7 @@
     <label-sequence>
       <label-item label="VHABERSUBJ"/>
       <label-item label="ADV"/>
-    </label-sequence> 
+    </label-sequence>  -->
    
   </forbid>
 
@@ -1719,7 +1765,8 @@
    </enforce-after>
   </enforce-rules>-->
   
-  <preferences>
+
+ <!-- <preferences>
    <prefer tags="vblex.pri.p3.sg"/>
    <prefer tags="vbser.pri.p3.sg"/>
    <prefer tags="vbhaver.pri.p3.sg"/>
@@ -1740,6 +1787,6 @@
    <prefer tags="vbser.pis.p3.sg"/>
    <prefer tags="vbhaver.pis.p3.sg"/>
    <prefer tags="vbmod.pis.p3.sg"/>
-  </preferences>
+  </preferences> -->
   
 </tagger>
